@@ -9,13 +9,11 @@ from supabase import Client
 
 class SyncAPIResource:
     client: httpx.Client
-    database: Client
     supabase: Client
     websocket: OuroWebSocket
 
     def __init__(self, ouro) -> None:
         self.client = ouro.client
         self.websocket = ouro.websocket
-        self.database = ouro.database
         self.supabase = ouro.supabase
         self.ouro = ouro
