@@ -1,14 +1,18 @@
-from datetime import datetime
-from typing import TYPE_CHECKING, Any, List, Literal, Optional, Union
+from typing import TYPE_CHECKING, List, Optional
 from uuid import UUID
 
-from pydantic import BaseModel, ConfigDict, Field
+from pydantic import BaseModel, Field
+
+from .asset import Asset
 
 if TYPE_CHECKING:
     from ouro.resources.conversations import ConversationMessages
 
     from ouro import Ouro
 
+from .file import File, FileData
+from .service import Route, Service
+
 __all__ = [
     "Asset",
     "PostContent",
@@ -17,30 +21,12 @@ __all__ = [
     "File",
     "FileData",
     "Dataset",
+    "Comment",
+    "Service",
+    "Route",
 ]
 
 
-class Asset(BaseModel):
-    id: UUID
-    user_id: UUID
-    org_id: UUID | None
-    name: str
-    visibility: str
-    asset_type: str
-    created_at: datetime
-    last_updated: datetime
-    description: Optional[str]
-    metadata: Optional[dict]
-    monetization: Optional[str]
-    price: Optional[float]
-    product_id: Optional[str]
-    price_id: Optional[str]
-    preview: Optional[dict]
-    cost_accounting: Optional[str]
-    cost_unit: Optional[str]
-    unit_cost: Optional[float]
-
-
 class PostContent(BaseModel):
     text: str
     data: dict = Field(
@@ -82,26 +68,6 @@ class Conversation(Asset):
         return self._messages
 
 
-class FileData(BaseModel):
-    signedUrl: Optional[str] = None
-    publicUrl: Optional[str] = None
-
-
-class FileMetadata(BaseModel):
-    id: UUID
-    name: str
-    path: str
-    size: int
-    type: str
-    bucket: Literal["public-files", "files"]
-    fullPath: str
-
-
-class File(Asset):
-    metadata: FileMetadata
-    data: Optional[FileData] = None
-
-
 class DatasetMetadata(BaseModel):
     table_name: str
     columns: List[str]
@@ -110,3 +76,7 @@ class DatasetMetadata(BaseModel):
 class Dataset(Asset):
     # metadata: Union[DatasetMetadata, Optional[FileMetadata]]
     preview: Optional[List[dict]] = None
+
+
+class Comment(Asset):
+    content: Optional[PostContent] = None
