@@ -24,80 +24,103 @@ class Datasets(SyncAPIResource):
         monetization: Optional[str] = None,
         price: Optional[float] = None,
         description: Optional[str] = None,
-    ):
-        df = data.copy()
-        # Get a sql safe table name from the name
-        table_name = name.replace(" ", "_").lower()
+        **kwargs,
+    ) -> Dataset:
+        try:
+            df = data.copy()
+            # Get a sql safe table name from the name
+            table_name = name.replace(" ", "_").lower()
 
-        # Reset the index if it exists to use as the primary key
-        index_name = df.index.name
-        if index_name:
-            df.reset_index(inplace=True)
+            # Reset the index if it exists to use as the primary key
+            index_name = df.index.name
+            if index_name:
+                df.reset_index(inplace=True)
 
-        create_table_sql = pd.io.sql.get_schema(
-            df,
-            name=table_name,
-            schema="datasets",
-            # TODO: Add support for primary keys
-            # keys=index_name
-        )
+            create_table_sql = pd.io.sql.get_schema(
+                df,
+                name=table_name,
+                schema="datasets",
+                # TODO: Add support for primary keys
+                # keys=index_name
+            )
 
-        create_table_sql = create_table_sql.replace(
-            "TIMESTAMP", "TIMESTAMP WITH TIME ZONE"
-        )
-        create_table_sql = create_table_sql.replace(
-            "CREATE TABLE", "CREATE TABLE IF NOT EXISTS"
-        )
+            create_table_sql = create_table_sql.replace(
+                "TIMESTAMP", "TIMESTAMP WITH TIME ZONE"
+            )
+            create_table_sql = create_table_sql.replace(
+                "CREATE TABLE", "CREATE TABLE IF NOT EXISTS"
+            )
 
-        log.debug(f"Creating a dataset:\n{create_table_sql}")
+            log.debug(f"Creating a dataset:\n{create_table_sql}")
 
-        body = {
-            "name": name,
-            "visibility": visibility,
-            "monetization": monetization,
-            "price": price,
-            "description": description,
-            "schema": create_table_sql,
-        }
+            # Create preview
+            preview = self._serialize_dataframe(df.head(12))
+            metadata = {
+                "table_name": table_name,
+                "schema": "datasets",
+                "columns": df.columns.tolist(),
+            }
 
-        # Filter out None values
-        body = {k: v for k, v in body.items() if v is not None}
+            body = {
+                "name": name,
+                "visibility": visibility,
+                "monetization": monetization,
+                "price": price,
+                "description": description,
+                "schema": create_table_sql,
+                **kwargs,
+                # Strictly enforce these fields
+                "source": "api",
+                "asset_type": "dataset",
+                "preview": preview,
+                "metadata": metadata,
+            }
 
-        request = self.client.post(
-            "/datasets/create/from-schema",
-            json={"dataset": body},
-        )
-        request.raise_for_status()
-        response = request.json()
+            # Filter out None values
+            body = {k: v for k, v in body.items() if v is not None}
 
-        log.info(response)
+            request = self.client.post(
+                "/datasets/create/from-schema",
+                json={"dataset": body},
+            )
+            request.raise_for_status()
+            response = request.json()
 
-        if response["error"]:
-            raise Exception(response["error"])
+            log.info(response)
 
-        # Good response, but no data to insert right now
-        if data is None:
-            return Dataset(**response["data"])
+            if response["error"]:
+                raise Exception(response["error"])
 
-        # Good response, we can now insert the data
-        created = Dataset(**response["data"])
-        table_name = created.metadata["table_name"]
+            # Good response, but no data to insert right now
+            if data is None:
+                return Dataset(**response["data"])
 
-        insert_data = self._serialize_dataframe(df)
-        # Insert the data into the table
-        # TODO: May need to batch insert
-        insert = self.database.table(table_name).insert(insert_data).execute()
-        if len(insert.data) > 0:
-            log.info(f"Inserted {len(insert.data)} rows into {table_name}")
+            # Good response, we can now insert the data
+            created = Dataset(**response["data"])
+            insert_data = self._serialize_dataframe(df)
 
-        # Update the dataset with a data preview
-        update = self.update(created.id, preview=insert_data[0:7])
+            # Insert the data into the table
+            # TODO: May need to batch insert
+            insert = (
+                self.supabase.schema("datasets")
+                .table(table_name)
+                .insert(insert_data)
+                .execute()
+            )
 
-        return created
+            if len(insert.data) > 0:
+                log.info(f"Inserted {len(insert.data)} rows into {table_name}")
 
-    def retrieve(self, id: str):
+            return created
+        except Exception as e:
+            log.error(e)
+            raise e
+        finally:
+            pass
+
+    def retrieve(self, id: str) -> Dataset:
         """
-        Retrieve a Dataset by its id
+        Retrieve a dataset by its id
         """
         request = self.client.get(
             f"/datasets/{id}",
@@ -108,9 +131,51 @@ class Datasets(SyncAPIResource):
             raise Exception(response["error"])
         return Dataset(**response["data"])
 
+    def stats(self, id: str) -> dict:
+        """
+        Retrieve a dataset's stats by its id
+        Returns a dict with the dataset's stats like row count, column count, etc.
+        """
+        request = self.client.get(
+            f"/datasets/{id}/stats",
+        )
+        request.raise_for_status()
+        response = request.json()
+        if response["error"]:
+            raise Exception(response["error"])
+        return response["data"]
+
+    def permissions(self, id: str) -> List[dict]:
+        """
+        Retrieve a dataset's permissions by its id
+        Returns a list of dicts, each representing a permission
+        """
+        request = self.client.get(
+            f"/datasets/{id}/permissions",
+        )
+        request.raise_for_status()
+        response = request.json()
+        if response["error"]:
+            raise Exception(response["error"])
+        return response["data"]
+
+    def schema(self, id: str) -> List[dict]:
+        """
+        Retrieve a dataset's schema
+        Returns a list of dicts, each representing a column in the dataset
+        """
+        request = self.client.get(
+            f"/datasets/{id}/schema",
+        )
+        request.raise_for_status()
+        response = request.json()
+        if response["error"]:
+            raise Exception(response["error"])
+        return response["data"]
+
     def query(self, id: str) -> pd.DataFrame:
         """
-        Query a Dataset's data by its id
+        Query a dataset's data by its id
         """
 
         if not id:
@@ -150,7 +215,10 @@ class Datasets(SyncAPIResource):
         """
         start = timer.time()
 
-        row_count = self.database.table(table_name).select("*", count="exact").execute()
+        # Set the schema to datasets
+        self.supabase.postgrest.schema("datasets")
+
+        row_count = self.supabase.table(table_name).select("*", count="exact").execute()
         row_count = row_count.count
 
         log.info(f"Loading {row_count} rows from datasets.{table_name}...")
@@ -160,33 +228,23 @@ class Datasets(SyncAPIResource):
             for i in range(0, row_count, 1_000_000):
                 log.debug(f"Loading rows {i} to {i+1_000_000}")
                 res = (
-                    self.database.table(table_name)
+                    self.supabase.table(table_name)
                     .select("*")
                     .range(i, i + 1_000_000)
                     .execute()
                 )
                 data.extend(res.data)
         else:
-            res = self.database.table(table_name).select("*").limit(1_000_000).execute()
+            res = self.supabase.table(table_name).select("*").limit(1_000_000).execute()
             data = res.data
 
         end = timer.time()
         log.info(f"Finished loading data in {round(end - start, 2)} seconds.")
 
-        return pd.DataFrame(data)
+        # Reset the schema
+        self.supabase.postgrest.schema("public")
 
-    def schema(self, id: str):
-        """
-        Retrieve a Dataset's schema
-        """
-        request = self.client.get(
-            f"/datasets/{id}/schema",
-        )
-        request.raise_for_status()
-        response = request.json()
-        if response["error"]:
-            raise Exception(response["error"])
-        return response["data"]
+        return pd.DataFrame(data)
 
     def update(
         self,
@@ -198,41 +256,61 @@ class Datasets(SyncAPIResource):
         data: Optional[pd.DataFrame] = None,
         monetization: Optional[str] = None,
         price: Optional[float] = None,
+        **kwargs,
     ):
         """
-        Update a Dataset's data by its id
+        Update a dataset by its id
         """
+        try:
+            body = {
+                "name": name,
+                "visibility": visibility,
+                "monetization": monetization,
+                "price": price,
+                "description": description,
+                "preview": preview,
+                **kwargs,
+            }
+            # Filter out None values
+            body = {k: v for k, v in body.items() if v is not None}
+            request = self.client.put(
+                f"/datasets/{id}",
+                json={"dataset": body},
+            )
+            request.raise_for_status()
+            response = request.json()
+            if response["error"]:
+                raise Exception(response["error"])
 
-        body = {
-            "name": name,
-            "visibility": visibility,
-            "monetization": monetization,
-            "price": price,
-            "description": description,
-            "preview": preview,
-        }
-        # Filter out None values
-        body = {k: v for k, v in body.items() if v is not None}
+            # Make the data update if it's provided
+            if data is not None:
+                table_name = self.retrieve(id).metadata["table_name"]
+                insert_data = self._serialize_dataframe(data)
+                # Set the schema to datasets
+                self.supabase.postgrest.schema("datasets")
+                insert = self.supabase.table(table_name).insert(insert_data).execute()
+                if len(insert.data) > 0:
+                    log.info(f"Inserted {len(insert.data)} rows into {table_name}")
 
-        request = self.client.put(
+            return Dataset(**response["data"])
+        except Exception as e:
+            log.error(e)
+            raise e
+        finally:
+            self.supabase.postgrest.schema("public")
+
+    def delete(self, id: str):
+        """
+        Delete a dataset by its id
+        """
+        request = self.client.delete(
             f"/datasets/{id}",
-            json={"dataset": body},
         )
         request.raise_for_status()
         response = request.json()
         if response["error"]:
             raise Exception(response["error"])
-
-        # Make the data update if it's provided
-        if data is not None:
-            table_name = self.retrieve(id).metadata["table_name"]
-            insert_data = self._serialize_dataframe(data)
-
-            insert = self.database.table(table_name).insert(insert_data).execute()
-            if len(insert.data) > 0:
-                log.info(f"Inserted {len(insert.data)} rows into {table_name}")
-
-        return Dataset(**response["data"])
+        return response["data"]
 
     def _serialize_dataframe(self, data: pd.DataFrame) -> List[dict]:
         """
