@@ -3,7 +3,7 @@ import logging
 import mimetypes
 import os
 import uuid
-from typing import List, Literal, Optional
+from typing import List, Literal, Optional, Union
 
 from ouro._resource import SyncAPIResource
 from ouro.models import File
@@ -250,7 +250,7 @@ class Files(SyncAPIResource):
     def share(
         self,
         file_id: str,
-        user_id: uuid.UUID | str,
+        user_id: Union[uuid.UUID, str],
         role: Literal["read", "write", "admin"] = "read",
     ) -> None:
         """Share a file with another user.
